@@ -20,7 +20,7 @@
 #endif
 
 #include <gtk/gtk.h>
-#include <glib/gi18n.h>
+#include <libxfce4ui/libxfce4ui.h>
 
 #include "common.h"
 #include "speedreader.h"
@@ -28,9 +28,6 @@
 
 typedef struct _XfdSpeedReaderPrivate			XfdSpeedReaderPrivate;
 
-#define XFD_SPEED_READER_GET_PRIVATE(obj)		(G_TYPE_INSTANCE_GET_PRIVATE((obj),\
-			XFD_SPEED_READER_TYPE, XfdSpeedReaderPrivate))
-
 struct _XfdSpeedReaderPrivate
 {
 	GtkWidget *first_page;
@@ -78,7 +75,7 @@ enum
 #define XFD_TITLE_RESUME _("_Resume")
 
 
-G_DEFINE_TYPE(XfdSpeedReader, xfd_speed_reader, GTK_TYPE_DIALOG);
+G_DEFINE_TYPE_WITH_PRIVATE(XfdSpeedReader, xfd_speed_reader, GTK_TYPE_DIALOG);
 
 static void sr_stop(XfdSpeedReader *dialog);
 static void sr_stop_timer(XfdSpeedReader *dialog);
@@ -102,8 +99,6 @@ static void xfd_speed_reader_class_init(XfdSpeedReaderClass *klass)
 
 	g_object_class = G_OBJECT_CLASS(klass);
 	g_object_class->finalize = xfd_speed_reader_finalize;
-
-	g_type_class_add_private((gpointer)klass, sizeof(XfdSpeedReaderPrivate));
 }
 
 
@@ -251,9 +246,9 @@ static void xfd_speed_reader_set_window_title(XfdSpeedReader *dialog, gint state
 {
 	gchar *title, *state_str, *name;
 	const gchar *button_label = _("S_top");
-	const gchar *button_image = "gtk-media-stop";
+	const gchar *button_image = "media-playback-stop";
 	gboolean pausable = TRUE;
-	XfdSpeedReaderPrivate *priv = XFD_SPEED_READER_GET_PRIVATE(dialog);
+	XfdSpeedReaderPrivate *priv = xfd_speed_reader_get_instance_private(dialog);
 
 	switch (state)
 	{
@@ -263,7 +258,7 @@ static void xfd_speed_reader_set_window_title(XfdSpeedReader *dialog, gint state
 		case XSR_STATE_FINISHED:
 			state_str = _("Finished");
 			button_label = _("_Back");
-			button_image = "gtk-go-back";
+			button_image = "go-previous";
 			pausable = FALSE;
 			break;
 		default:
@@ -285,7 +280,7 @@ static void xfd_speed_reader_set_window_title(XfdSpeedReader *dialog, gint state
 
 static void sr_set_label_text(XfdSpeedReader *dialog)
 {
-	XfdSpeedReaderPrivate *priv = XFD_SPEED_READER_GET_PRIVATE(dialog);
+	XfdSpeedReaderPrivate *priv = xfd_speed_reader_get_instance_private(dialog);
 
 	if (NZV(priv->group->str))
 		gtk_label_set_text(GTK_LABEL(priv->display_label), priv->group->str);
@@ -295,16 +290,17 @@ static void sr_set_label_text(XfdSpeedReader *dialog)
 
 static gboolean sr_timer(gpointer data)
 {
-	XfdSpeedReaderPrivate *priv = XFD_SPEED_READER_GET_PRIVATE(data);
 	gsize i;
+	XfdSpeedReader *dialog = XFD_SPEED_READER(data);
+	XfdSpeedReaderPrivate *priv = xfd_speed_reader_get_instance_private(dialog);
 
 	if (priv->paused)
 		return TRUE;
 
 	if (priv->word_idx >= priv->words_len)
 	{
-		sr_stop(XFD_SPEED_READER(data));
-		xfd_speed_reader_set_window_title(XFD_SPEED_READER(data), XSR_STATE_FINISHED);
+		sr_stop(dialog);
+		xfd_speed_reader_set_window_title(dialog, XSR_STATE_FINISHED);
 		return FALSE;
 	}
 
@@ -349,7 +345,6 @@ static gboolean sr_timer(gpointer data)
 
 static void sr_start(XfdSpeedReader *dialog)
 {
-	XfdSpeedReaderPrivate *priv = XFD_SPEED_READER_GET_PRIVATE(dialog);
 	gint wpm, grouping;
 	gint interval;
 	gchar *fontname;
@@ -359,6 +354,8 @@ static void sr_start(XfdSpeedReader *dialog)
 	GtkCssProvider *provider;
 	PangoFontDescription *font;
 
+	XfdSpeedReaderPrivate *priv = xfd_speed_reader_get_instance_private(dialog);
+
 	/* clear the label text */
 	gtk_label_set_text(GTK_LABEL(priv->display_label), NULL);
 
@@ -440,7 +437,7 @@ static void sr_start(XfdSpeedReader *dialog)
 
 static void sr_stop_timer(XfdSpeedReader *dialog)
 {
-	XfdSpeedReaderPrivate *priv = XFD_SPEED_READER_GET_PRIVATE(dialog);
+	XfdSpeedReaderPrivate *priv = xfd_speed_reader_get_instance_private(dialog);
 
 	if (priv->timer_id > 0)
 	{
@@ -465,18 +462,18 @@ static void sr_stop(XfdSpeedReader *dialog)
 
 static void sr_pause(XfdSpeedReader *dialog, gboolean paused)
 {
-	XfdSpeedReaderPrivate *priv = XFD_SPEED_READER_GET_PRIVATE(dialog);
+	XfdSpeedReaderPrivate *priv = xfd_speed_reader_get_instance_private(dialog);
 
 	if (paused)
 	{
 		gtk_button_set_image(GTK_BUTTON(priv->button_pause),
-			gtk_image_new_from_icon_name("gtk-media-play", GTK_ICON_SIZE_MENU));
+			gtk_image_new_from_icon_name("media-playback-start", GTK_ICON_SIZE_MENU));
 		gtk_button_set_label(GTK_BUTTON(priv->button_pause), XFD_TITLE_RESUME);
 	}
 	else
 	{
 		gtk_button_set_image(GTK_BUTTON(priv->button_pause),
-			gtk_image_new_from_icon_name("gtk-media-pause", GTK_ICON_SIZE_MENU));
+			gtk_image_new_from_icon_name("media-playback-pause", GTK_ICON_SIZE_MENU));
 		gtk_button_set_label(GTK_BUTTON(priv->button_pause), XFD_TITLE_PAUSE);
 	}
 	/* set the new value */
@@ -486,7 +483,7 @@ static void sr_pause(XfdSpeedReader *dialog, gboolean paused)
 
 static void xfd_speed_reader_response_cb(XfdSpeedReader *dialog, gint response, gpointer data)
 {
-	XfdSpeedReaderPrivate *priv = XFD_SPEED_READER_GET_PRIVATE(dialog);
+	XfdSpeedReaderPrivate *priv = xfd_speed_reader_get_instance_private(dialog);
 
 	if (response == GTK_RESPONSE_CLOSE || response == GTK_RESPONSE_DELETE_EVENT)
 	{
@@ -529,8 +526,8 @@ static void sr_open_clicked_cb(GtkButton *button, XfdSpeedReader *window)
 	dialog = gtk_file_chooser_dialog_new(_("Choose a file to load"),
 		GTK_WINDOW(window),
 		GTK_FILE_CHOOSER_ACTION_OPEN,
-		"gtk-cancel", GTK_RESPONSE_CANCEL,
-		"gtk-open", GTK_RESPONSE_ACCEPT,
+		_("_Cancel"), GTK_RESPONSE_CANCEL,
+		_("_Open"), GTK_RESPONSE_ACCEPT,
 		NULL);
 
 	gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_ACCEPT);
@@ -545,7 +542,7 @@ static void sr_open_clicked_cb(GtkButton *button, XfdSpeedReader *window)
 		gchar *filename;
 		gchar *text;
 		gsize len;
-		XfdSpeedReaderPrivate *priv = XFD_SPEED_READER_GET_PRIVATE(window);
+		XfdSpeedReaderPrivate *priv = xfd_speed_reader_get_instance_private(window);
 
 		filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
 		if (g_file_get_contents(filename, &text, &len, NULL))
@@ -594,9 +591,9 @@ static void xfd_speed_reader_init(XfdSpeedReader *dialog)
 {
 	GtkWidget *label_intro, *label_words, *label_font, *label_grouping, *label_grouping_desc;
 	GtkWidget *vbox, *hbox_words, *hbox_font, *hbox_grouping, *swin, *textview;
-	GtkWidget *vbox_text_buttons, *hbox_text, *button_clear, *button_paste, *button_open;
+	GtkWidget *vbox_text_buttons, *hbox_text, *button_clear, *button_paste, *button_open, *button_close;
 	GtkSizeGroup *sizegroup;
-	XfdSpeedReaderPrivate *priv = XFD_SPEED_READER_GET_PRIVATE(dialog);
+	XfdSpeedReaderPrivate *priv = xfd_speed_reader_get_instance_private(dialog);
 
 	gtk_window_set_destroy_with_parent(GTK_WINDOW(dialog), TRUE);
 	gtk_window_set_default_size(GTK_WINDOW(dialog), 400, 330);
@@ -673,16 +670,16 @@ static void xfd_speed_reader_init(XfdSpeedReader *dialog)
 					GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	gtk_container_add(GTK_CONTAINER(swin), textview);
 
-	button_open = gtk_button_new_from_icon_name("gtk-open", GTK_ICON_SIZE_MENU);
+	button_open = gtk_button_new_from_icon_name("document-open", GTK_ICON_SIZE_MENU);
 	g_signal_connect(button_open, "clicked", G_CALLBACK(sr_open_clicked_cb), dialog);
 	gtk_widget_set_tooltip_text(button_open, _("Load the contents of a file"));
 
-	button_paste = gtk_button_new_from_icon_name("gtk-paste", GTK_ICON_SIZE_MENU);
+	button_paste = gtk_button_new_from_icon_name("edit-paste", GTK_ICON_SIZE_MENU);
 	g_signal_connect(button_paste, "clicked", G_CALLBACK(sr_paste_clicked_cb), priv->buffer);
 	gtk_widget_set_tooltip_text(button_paste,
 		_("Clear the contents of the text field and paste the contents of the clipboard"));
 
-	button_clear = gtk_button_new_from_icon_name("gtk-clear", GTK_ICON_SIZE_MENU);
+	button_clear = gtk_button_new_from_icon_name("edit-clear", GTK_ICON_SIZE_MENU);
 	g_signal_connect(button_clear, "clicked", G_CALLBACK(sr_clear_clicked_cb), priv->buffer);
 	gtk_widget_set_tooltip_text(button_clear, _("Clear the contents of the text field"));
 
@@ -695,16 +692,22 @@ static void xfd_speed_reader_init(XfdSpeedReader *dialog)
 	gtk_box_pack_start(GTK_BOX(hbox_text), swin, TRUE, TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox_text), vbox_text_buttons, FALSE, FALSE, 3);
 
-	priv->button_pause = gtk_dialog_add_button(GTK_DIALOG(dialog), "gtk-media-pause", RESPONSE_PAUSE);
+	priv->button_pause = gtk_dialog_add_button(GTK_DIALOG(dialog), _("P_ause"), RESPONSE_PAUSE);
 	priv->button_start = gtk_dialog_add_button(GTK_DIALOG(dialog), _("_Start"), RESPONSE_START);
-	priv->button_stop = gtk_dialog_add_button(GTK_DIALOG(dialog), "gtk-media-stop", RESPONSE_STOP);
-	gtk_dialog_add_button(GTK_DIALOG(dialog), "gtk-close", GTK_RESPONSE_CLOSE);
+	priv->button_stop = gtk_dialog_add_button(GTK_DIALOG(dialog), _("S_top"), RESPONSE_STOP);
+	button_close = gtk_dialog_add_button(GTK_DIALOG(dialog), _("_Close"), GTK_RESPONSE_CLOSE);
 
 	gtk_widget_hide(priv->button_pause);
 	gtk_widget_hide(priv->button_stop);
 
+	gtk_button_set_image(GTK_BUTTON(priv->button_pause),
+		gtk_image_new_from_icon_name("media-playback-pause", GTK_ICON_SIZE_MENU));
 	gtk_button_set_image(GTK_BUTTON(priv->button_start),
-		gtk_image_new_from_icon_name("gtk-media-play", GTK_ICON_SIZE_MENU));
+		gtk_image_new_from_icon_name("media-playback-start", GTK_ICON_SIZE_MENU));
+	gtk_button_set_image(GTK_BUTTON(priv->button_stop),
+		gtk_image_new_from_icon_name("media-playback-stop", GTK_ICON_SIZE_MENU));
+	gtk_button_set_image(GTK_BUTTON(button_close),
+		gtk_image_new_from_icon_name("window-close", GTK_ICON_SIZE_MENU));
 
 	g_signal_connect(dialog, "response", G_CALLBACK(xfd_speed_reader_response_cb), NULL);
 
@@ -740,7 +743,7 @@ static void xfd_speed_reader_init(XfdSpeedReader *dialog)
 GtkWidget *xfd_speed_reader_new(GtkWindow *parent, DictData *dd)
 {
 	GtkWidget *dialog = g_object_new(XFD_SPEED_READER_TYPE, "transient-for", parent, NULL);
-	XfdSpeedReaderPrivate *priv = XFD_SPEED_READER_GET_PRIVATE(dialog);
+	XfdSpeedReaderPrivate *priv = xfd_speed_reader_get_instance_private(XFD_SPEED_READER (dialog));
 
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(priv->spin_wpm), dd->speedreader_wpm);
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(priv->spin_grouping), dd->speedreader_grouping);
